@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: MailPost.pm 1645 2008-02-06 15:40:18Z hikarin $
+# $Id: MailPost.pm 1902 2009-12-31 10:02:21Z hikarin $
 #
 
 package Img0ch::App::MailPost;
@@ -100,10 +100,9 @@ sub redirect_success {
         }
     );
 
-    my $charset = $iConfig->get('DefaultCharset');
-    $iRequest->send_http_header( 'text/html', $charset );
+    $iRequest->send_http_header( 'text/html', $iBBS->get_encoding() );
     $iTemplate->flush( sub { ${ $_[0] } =~ s/\n//gxms; ${ $_[0] } } );
-    1;
+    return 1;
 }
 
 sub get_mail_via_pop3 {
@@ -168,8 +167,6 @@ sub get_mail_via_imap {
     if ( $imap->unseen() ) {
         my @messages = $imap->messages();
         my $i        = shift @messages;
-        use Data::Dumper;
-        die Dumper @messages, $i;
         @$mail_rec = split /\r\n/xms, $imap->message_string($i);
         $imap->delete_message($i)
             or $iKernel->throw_exception( $imap->LastError() );
@@ -276,8 +273,8 @@ sub set_parameters_from_mail {
         $subject =~ s/\s*\z//xms;
         my ( $name, $mail, $rmkey ) = split '<>', $subject, 3;
         $iRequest->set_param_internal( 'FROM', $name );
-        $iRequest->set_param_internal( 'mail', ($mail || '') );
-        $iRequest->set_param_internal( 'pass', ($rmkey || '') )
+        $iRequest->set_param_internal( 'mail', ( $mail  || '' ) );
+        $iRequest->set_param_internal( 'pass', ( $rmkey || '' ) );
     }
     else {
         $iRequest->set_param_internal( 'FROM', $subject );
@@ -339,7 +336,9 @@ sub _get_host {
             and $from !~ /ezweb\.ne\.jp/xms
             and $from !~ /jp-[dhtckrnsq]\.ne\.jp/xms
             and $from !~ /[dhtckrnsq]\.vodafone\.ne\.jp/xms
-            and $from !~ /softbank\.ne\.jp/xms )
+            and $from !~ /softbank\.ne\.jp/xms
+            and $from !~ /disney\.ne\.jp/xms
+            and $from !~ /i\.softbank\.jp/xms )
         {
             $iApp->set_error('MAILPOST_FROM_NOT_MOBILE_ADDRESS');
             return 0;
