@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Maple.pm 1876 2009-12-01 17:55:47Z hikarin $
+# $Id: Maple.pm 1977 2010-01-23 16:05:54Z hikarin $
 #
 
 package Img0ch::Maple;
@@ -22,8 +22,8 @@ package Img0ch::Maple;
 use strict;
 use Fcntl qw(:DEFAULT :flock);
 
-$Img0ch::Maple::RCS_ID  = '$Id: Maple.pm 1876 2009-12-01 17:55:47Z hikarin $';
-$Img0ch::Maple::VERSION = '3.1.4';
+$Img0ch::Maple::RCS_ID  = '$Id: Maple.pm 1977 2010-01-23 16:05:54Z hikarin $';
+$Img0ch::Maple::VERSION = '3.1.6';
 $Img0ch::Maple::revision = do {
     my @rv = $Img0ch::Maple::RCS_ID =~ /(\d+)/xms;
     $rv[0];
@@ -256,22 +256,24 @@ sub create_repository_subdirs {
 }
 
 my $repository_type = {
-    'Archive'    => 'Archive',
-    'BDB'        => 'BDB',
-    'BerkeleyDB' => 'BDB',
-    'CDB'        => 'CDB',
-    'CDB_File'   => 'CDB',
-    'Compressed' => 'Archive',
-    'DBMDeep'    => 'DD',
-    'DD'         => 'DD',
-    'Depot'      => 'Qdepot',
-    'FlatFile'   => 'Simple',
-    'QDBM'       => 'Qdepot',
-    'Qdepot'     => 'Qdepot',
-    'Qvilla'     => 'Qvilla',
-    'Simple'     => 'Simple',
-    'Storable'   => 'Storable',
-    'Villa'      => 'Qvilla',
+    'Archive'      => 'Archive',
+    'BDB'          => 'BDB',
+    'BerkeleyDB'   => 'BDB',
+    'CDB'          => 'CDB',
+    'CDB_File'     => 'CDB',
+    'Compressed'   => 'Archive',
+    'DBMDeep'      => 'DD',
+    'DD'           => 'DD',
+    'Depot'        => 'Qdepot',
+    'FlatFile'     => 'Simple',
+    'QDBM'         => 'Qdepot',
+    'Qdepot'       => 'Qdepot',
+    'Qvilla'       => 'Qvilla',
+    'Simple'       => 'Simple',
+    'Storable'     => 'Storable',
+    'TC'           => 'TC',
+    'TokyoCabinet' => 'TC',
+    'Villa'        => 'Qvilla',
 };
 
 sub get_repos_type { $repository_type->{ $_[1] } || 'Simple' }
