@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Action.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Action.pm 1960 2010-01-23 12:16:18Z hikarin $
 #
 
 package Zeromin::Log::Action;
@@ -220,7 +220,7 @@ sub to_array_with_page {
 
 sub _page {
     my ( $entries, $item_per_page, $offset ) = @_;
-    require Data::Page;
+    defined $Data::Page::VERSION or require Data::Page;
     my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
     return ( [ $page->splice($entries) ], $page );
 }
@@ -234,61 +234,39 @@ sub _retrive {
     {
         $iRepos->iterate(
             sub {
-                my ( $key, $value, $iRepos, $seen, $ret, $zUser ) = @_;
+                my ( $key, $value, $seen ) = @_;
                 if ( $key =~ m{\AI:L:A\.(\d+?)\.(.+?)\.(\w+)\z}xms ) {
                     my ( $date, $mil, $name ) = ( $1, $2, $3 );
                     my $prefix = "I:L:A.${date}.${mil}";
                     exists $seen->{$prefix} and return 0;
-                    $seen->{$prefix} = 1;
-                    my $user
-                        = $name eq 'user'
-                        ? $$value
-                        : $iRepos->get("${prefix}.user");
-                    my $class
-                        = $name eq 'class'
-                        ? $$value
-                        : $iRepos->get("${prefix}.class");
-                    my $ip
-                        = $name eq 'ip'
-                        ? $$value
-                        : $iRepos->get("${prefix}.ip");
-                    my $ok
-                        = $name eq 'ok'
-                        ? $$value
-                        : $iRepos->get("${prefix}.ok");
-                    my $reason
-                        = $name eq 'reason'
-                        ? $$value
-                        : $iRepos->get("${prefix}.reason");
-                    my $param
-                        = $name eq 'param'
-                        ? $$value
-                        : $iRepos->get("${prefix}.param");
-                    push @$ret,
-                        {
-                        class  => $class,
-                        date   => $date,
-                        ip     => $ip,
-                        ok     => $ok,
-                        reason => sprintf(
-                            $iRepos->get("${prefix}.reason"),
-                            @{  thaw(
-                                    $iRepos->get_binary("${prefix}.param")
-                                )
-                                },
-                        ),
-                        user =>
-                            ( $zUser ? $zUser->get_user_name($user) : $user ),
-                        };
+                    $seen->{$prefix} = $date;
                 }
                 return 0;
             },
-            $iRepos,
             $seen,
-            $ret,
-            $zUser,
         );
+        while ( my ( $prefix, $date ) = each %$seen ) {
+            my $user   = $iRepos->get("${prefix}.user");
+            my $class  = $iRepos->get("${prefix}.class");
+            my $ip     = $iRepos->get("${prefix}.ip");
+            my $ok     = $iRepos->get("${prefix}.ok");
+            my $reason = $iRepos->get("${prefix}.reason");
+            my $param  = $iRepos->get("${prefix}.param");
+            push @$ret,
+                {
+                class  => $class,
+                date   => $date,
+                ip     => $ip,
+                ok     => $ok,
+                reason => sprintf(
+                    $iRepos->get("${prefix}.reason"),
+                    @{ thaw( $iRepos->get_binary("${prefix}.param") ) },
+                ),
+                user => ( $zUser ? $zUser->get_user_name($user) : $user ),
+                };
+        }
     }
+
     @$ret = sort { $b->{date} cmp $a->{date} } @$ret;
     return $ret;
 }
