@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Error.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Error.pm 1960 2010-01-23 12:16:18Z hikarin $
 #
 
 package Zeromin::Log::Error;
@@ -62,7 +62,7 @@ sub _retrive {
     {
         $iRepos->iterate(
             sub {
-                my ( $key, $value, $iRepos, $seen, $ret ) = @_;
+                my ( $key, $value, $seen ) = @_;
                 if ($key =~ m{
                     \AI:L:E\.(.*?)\.(.*?)\.(\d*?)\.(.*?)\.(\w+)\z
                     }xms
@@ -72,30 +72,26 @@ sub _retrive {
                         = ( $1, $2, $3, $4, $5 );
                     my $prefix = "I:L:E.${bbs}.${thread_key}.${date}.${mil}";
                     exists $seen->{$prefix} and return 0;
-                    $seen->{$prefix} = 1;
-                    my $error
-                        = $name eq 'error'
-                        ? $$value
-                        : $iRepos->get("${prefix}.error");
-                    my $ip
-                        = $name eq 'ip'
-                        ? $$value
-                        : $iRepos->get("${prefix}.ip");
-                    push @$ret,
-                        {
-                        bbs   => $bbs,
-                        key   => $thread_key,
-                        ip    => $ip,
-                        date  => $date,
-                        error => $error,
-                        };
+                    $seen->{$prefix} = $date;
                 }
                 return 0;
             },
-            $iRepos,
             $seen,
-            $ret,
         );
+        while ( my ( $prefix, $date ) = each %$seen ) {
+            my ( undef, $bbs, $thread_key, $date, undef ) = split /\./,
+                $prefix;
+            my $error = $iRepos->get("${prefix}.error");
+            my $ip    = $iRepos->get("${prefix}.ip");
+            push @$ret,
+                {
+                bbs   => $bbs,
+                key   => $thread_key,
+                ip    => $ip,
+                date  => $date,
+                error => $error,
+                };
+        }
     }
     @$ret = sort { $b->{date} cmp $a->{date} } @$ret;
     return $ret;
